"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const react_1 = require("react");
const react_native_1 = require("react-native");
const { UIManager } = react_native_1.NativeModules;
const useStateWithLayoutAnimation = (initialValue, setLayoutAnimationEnabledExperimental = true) => {
    react_1.useEffect(() => {
        if (setLayoutAnimationEnabledExperimental) {
            UIManager.setLayoutAnimationEnabledExperimental &&
                UIManager.setLayoutAnimationEnabledExperimental(true);
        }
    }, [setLayoutAnimationEnabledExperimental]);
    const [state, setState] = react_1.useState(initialValue);
    const curriedSetState = react_1.useCallback((animationFn) => (nextState, onAnimationDidEnd) => {
        animationFn(onAnimationDidEnd);
        setState(nextState);
    }, []);
    const spring = curriedSetState(react_native_1.LayoutAnimation.spring);
    const linear = curriedSetState(react_native_1.LayoutAnimation.linear);
    const easeInEaseOut = curriedSetState(react_native_1.LayoutAnimation.easeInEaseOut);
    const noAnimation = (nextState) => setState(nextState);
    const stateSetters = react_1.useRef({
        spring,
        linear,
        easeInEaseOut,
        noAnimation,
    }).current;
    return [state, stateSetters];
};
exports.default = useStateWithLayoutAnimation;
